@@ -600,7 +600,11 @@ class IrcBot(object):
         async with trio.open_nursery() as nursery:
             async with self.send_message_channel, self.send_db_operation_channel:
                 async for data in s:
-                    data = data.decode("utf-8")
+                    try:
+                        data = data.decode("utf-8")
+                    except UnicodeDecodeError:
+                        logging.warning("Decode error")
+                        continue
                     debug(
                         "DECODED DATA FROM SERVER: \n", 40 * "-", "\n", data, 40 * "-", "\n"
                     )
